@@ -2,46 +2,35 @@
 ### Encoding: ISO8859-15
 
 ###################################################
-### code chunk number 1: bimets.Rnw:61-62
+### code chunk number 1: bimets.Rnw:61-63
 ###################################################
 options( prompt = "R> ", continue = "   " )
-
-
-###################################################
-### code chunk number 2: bimets.Rnw:84-85 (eval = FALSE)
-###################################################
-## install.packages('bimets')
-
-
-###################################################
-### code chunk number 3: bimets.Rnw:87-88
-###################################################
 library(bimets)
 
 
 ###################################################
-### code chunk number 4: bimets.Rnw:97-99
+### code chunk number 2: bimets.Rnw:77-79
 ###################################################
 #yearly time series
 myTS <- TIMESERIES(1:10,START=as.Date('2000-01-01'),FREQ=1)
 
 
 ###################################################
-### code chunk number 5: bimets.Rnw:102-104
+### code chunk number 3: bimets.Rnw:82-84
 ###################################################
 #monthly time series
 myTS <- TIMESERIES(1:10,START=c(2002,3),FREQ='M')
 
 
 ###################################################
-### code chunk number 6: bimets.Rnw:124-126
+### code chunk number 4: bimets.Rnw:104-106
 ###################################################
 #create a daily time series
 myTS <- TIMESERIES((1:100),START=c(2000,1),FREQ='D')
 
 
 ###################################################
-### code chunk number 7: computation
+### code chunk number 5: computation
 ###################################################
 myTS[1:3]                       #get first three obs.
 myTS['2000-01-12']              #get Jan 12, 2000 data
@@ -54,28 +43,28 @@ myTS[[2000,100]] <- c(-1,-2,-3) #extend time series starting from period 100
 
 
 ###################################################
-### code chunk number 8: bimets.Rnw:145-147
+### code chunk number 6: bimets.Rnw:125-127
 ###################################################
 #create a monthly time series
 myMonthlyTS <- TIMESERIES(1:100,START=c(2000,1),FREQ='M')
 
 
 ###################################################
-### code chunk number 9: bimets.Rnw:149-151
+### code chunk number 7: bimets.Rnw:129-131
 ###################################################
 #convert to yearly time series using the average as aggregation fun
 myYearlyTS <- YEARLY(myMonthlyTS,'AVE')
 
 
 ###################################################
-### code chunk number 10: bimets.Rnw:153-155
+### code chunk number 8: bimets.Rnw:133-135
 ###################################################
 #convert to daily using central interpolation as disaggregation fun
 myDailyTS <- DAILY(myMonthlyTS,'INTERP_CENTER')
 
 
 ###################################################
-### code chunk number 11: bimets.Rnw:175-178
+### code chunk number 9: bimets.Rnw:155-158
 ###################################################
 #define two time series
 myTS1 <- TIMESERIES(1:100,START=c(2000,1),FREQ='M')
@@ -83,28 +72,28 @@ myTS2 <- TIMESERIES(-(1:100),START=c(2005,1),FREQ='M')
 
 
 ###################################################
-### code chunk number 12: bimets.Rnw:180-182
+### code chunk number 10: bimets.Rnw:160-162
 ###################################################
 #extend time series up to Apr 2020 with quadratic formula
 myExtendedTS <- TSEXTEND(myTS1,UPTO = c(2020,4),EXTMODE = 'QUADRATIC')
 
 
 ###################################################
-### code chunk number 13: bimets.Rnw:184-186
+### code chunk number 11: bimets.Rnw:164-166
 ###################################################
 #merge two time series with sum
 myMergedTS <- TSMERGE(myExtendedTS,myTS2,fun = 'SUM')
 
 
 ###################################################
-### code chunk number 14: bimets.Rnw:188-190
+### code chunk number 12: bimets.Rnw:168-170
 ###################################################
 #project time series on arbitrary time range
 myProjectedTS <- TSPROJECT(myMergedTS,TSRANGE = c(2004,2,2006,4))
 
 
 ###################################################
-### code chunk number 15: bimets.Rnw:192-195
+### code chunk number 13: bimets.Rnw:172-175
 ###################################################
 #lag and delta% time series
 myLagTS <- TSLAG(myProjectedTS,2)
@@ -112,14 +101,14 @@ myDeltaPTS <- TSDELTAP(myLagTS,2)
 
 
 ###################################################
-### code chunk number 16: bimets.Rnw:197-199
+### code chunk number 14: bimets.Rnw:177-179
 ###################################################
 #moving average
 myMovAveTS <- MOVAVG(myDeltaPTS,5)
 
 
 ###################################################
-### code chunk number 17: bimets.Rnw:201-206
+### code chunk number 15: bimets.Rnw:181-186
 ###################################################
 #print data
 TABIT(myMovAveTS,
@@ -129,7 +118,7 @@ TABIT(myMovAveTS,
 
 
 ###################################################
-### code chunk number 18: bimets.Rnw:232-267
+### code chunk number 16: bimets.Rnw:212-247
 ###################################################
 klein1.txt <- "
 MODEL 
@@ -169,19 +158,19 @@ END
 
 
 ###################################################
-### code chunk number 19: bimets.Rnw:473-474
+### code chunk number 17: bimets.Rnw:471-472
 ###################################################
 kleinModel <- LOAD_MODEL(modelText = klein1.txt)
 
 
 ###################################################
-### code chunk number 20: bimets.Rnw:483-484
+### code chunk number 18: bimets.Rnw:481-482
 ###################################################
 kleinModel$behaviorals$cn
 
 
 ###################################################
-### code chunk number 21: bimets.Rnw:490-495
+### code chunk number 19: bimets.Rnw:488-493
 ###################################################
 kleinModel$incidence_matrix
 kleinModel$vpre
@@ -191,7 +180,7 @@ kleinModel$vpost
 
 
 ###################################################
-### code chunk number 22: bimets.Rnw:503-538
+### code chunk number 20: bimets.Rnw:501-536
 ###################################################
 kleinModelData <- list(  
     cn  =TIMESERIES(39.8,41.9,45,49.2,50.6,52.6,55.1,56.2,57.3,57.8,
@@ -231,7 +220,7 @@ kleinModel <- LOAD_MODEL_DATA(kleinModel,kleinModelData)
 
 
 ###################################################
-### code chunk number 23: computation
+### code chunk number 21: computation
 ###################################################
 
 lhsKlein1.txt <- "
@@ -282,7 +271,7 @@ END"
 
 
 ###################################################
-### code chunk number 24: computation
+### code chunk number 22: computation
 ###################################################
 
 #adjust the original data in order to estimate and to simulate the model
@@ -294,7 +283,7 @@ lhsKleinModelData <- within(kleinModelData,{
 
 
 ###################################################
-### code chunk number 25: computation
+### code chunk number 23: computation
 ###################################################
 
 lhsKleinModel <- LOAD_MODEL(modelText = lhsKlein1.txt)
@@ -302,7 +291,7 @@ lhsKleinModel <- LOAD_MODEL_DATA(lhsKleinModel,lhsKleinModelData)
 
 
 ###################################################
-### code chunk number 26: computation
+### code chunk number 24: computation
 ###################################################
 
 #ESTIMATE and SIMULATE functions are described later
@@ -311,19 +300,19 @@ lhsKleinModel <- SIMULATE(lhsKleinModel, TSRANGE = c(1925,1,1930,1))
 
 
 ###################################################
-### code chunk number 27: bimets.Rnw:637-638
+### code chunk number 25: bimets.Rnw:635-636
 ###################################################
 kleinModel <- ESTIMATE(kleinModel, quietly=TRUE)
 
 
 ###################################################
-### code chunk number 28: bimets.Rnw:643-644
+### code chunk number 26: bimets.Rnw:641-642
 ###################################################
 kleinModel <- ESTIMATE(kleinModel, eqList=c('cn'))
 
 
 ###################################################
-### code chunk number 29: bimets.Rnw:649-659
+### code chunk number 27: bimets.Rnw:647-657
 ###################################################
 #print estimated coefficients
 kleinModel$behaviorals$cn$coefficients
@@ -338,7 +327,7 @@ kleinModel$behaviorals$cn$statistics$LogLikelihood
 
 
 ###################################################
-### code chunk number 30: bimets.Rnw:667-712
+### code chunk number 28: bimets.Rnw:665-710
 ###################################################
 #define model
 advancedKlein1.txt <- 
@@ -388,7 +377,7 @@ END"
 
 
 ###################################################
-### code chunk number 31: bimets.Rnw:714-717
+### code chunk number 29: bimets.Rnw:712-715
 ###################################################
 #load model and data
 advancedKleinModel <- LOAD_MODEL(modelText=advancedKlein1.txt)
@@ -396,14 +385,14 @@ advancedKleinModel <- LOAD_MODEL_DATA(advancedKleinModel,kleinModelData)
 
 
 ###################################################
-### code chunk number 32: bimets.Rnw:719-721
+### code chunk number 30: bimets.Rnw:717-719
 ###################################################
 #estimate model
 advancedKleinModel <- ESTIMATE(advancedKleinModel)
 
 
 ###################################################
-### code chunk number 33: bimets.Rnw:756-763
+### code chunk number 31: bimets.Rnw:754-761
 ###################################################
 #chow test for the consumption equation
 #base TSRANGE set to 1921/1935
@@ -415,34 +404,34 @@ kleinModelChow <- ESTIMATE(kleinModel
 
 
 ###################################################
-### code chunk number 34: bimets.Rnw:834-856
+### code chunk number 32: bimets.Rnw:832-854
 ###################################################
-#FORECAST GNP in 1942 and 1943 
-#we need to extend exogenous variables in 1942 and 1943
+#FORECAST GNP in 1942:1944
+#we need to extend exogenous variables in 1942 up to 1944
 #in this exercise we perform a simple time series extension
 kleinModel$modelData <- within(kleinModel$modelData,{
-                    w2   = TSEXTEND(w2,  UPTO=c(1943,1))
-                    t    = TSEXTEND(t,   UPTO=c(1943,1))
-                    g    = TSEXTEND(g,   UPTO=c(1943,1))
-                    time = TSEXTEND(time,UPTO=c(1943,1)
-                                     ,EXTMODE='LINEAR')
-                    })
+            w2   = TSEXTEND(w2,  UPTO=c(1944,1),EXTMODE='CONSTANT')
+            t    = TSEXTEND(t,   UPTO=c(1944,1),EXTMODE='CONSTANT')
+            g    = TSEXTEND(g,   UPTO=c(1944,1),EXTMODE='CONSTANT')
+            time = TSEXTEND(time,UPTO=c(1944,1),EXTMODE='LINEAR')
+            })
 
  
 #simulate model
 kleinModel <- SIMULATE(kleinModel
-                  ,simType='FORECAST'
-                  ,TSRANGE=c(1940,1,1943,1)
-                  ,simConvergence=0.00001
-                  ,simIterLimit=100
-                  ,quietly=TRUE
-                  )
+            ,simType='FORECAST'
+            ,TSRANGE=c(1941,1,1944,1)
+            ,simConvergence=0.00001
+            ,simIterLimit=100
+            ,quietly=TRUE
+            )
+
 #get forecasted GNP
 TABIT(kleinModel$simulation$y)
 
 
 ###################################################
-### code chunk number 35: computation
+### code chunk number 33: computation
 ###################################################
 #STATIC SIMULATION EXAMPLE WITH EXOGENIZATION AND CONSTANT ADJUSTMENTS
  
@@ -472,7 +461,7 @@ kleinModel <- SIMULATE(kleinModel
 
 
 ###################################################
-### code chunk number 36: bimets.Rnw:947-954
+### code chunk number 34: bimets.Rnw:945-952
 ###################################################
 kleinModel <- MULTMATRIX(kleinModel,
                         TSRANGE=c(1941,1,1941,1),
@@ -484,7 +473,7 @@ kleinModel$MultiplierMatrix
 
 
 ###################################################
-### code chunk number 37: bimets.Rnw:960-969
+### code chunk number 35: bimets.Rnw:958-967
 ###################################################
 #multi-period interim multipliers
 kleinModel <- MULTMATRIX(kleinModel,
@@ -498,7 +487,7 @@ kleinModel$MultiplierMatrix
 
 
 ###################################################
-### code chunk number 38: bimets.Rnw:992-998
+### code chunk number 36: bimets.Rnw:990-996
 ###################################################
 #we want an arbitrary value on Consumption of 66 in 1940 and 78 in 1941
 #we want an arbitrary value on GNP of 77 in 1940 and 98 in 1941
@@ -509,7 +498,7 @@ kleinTargets <- list(
 
 
 ###################################################
-### code chunk number 39: computation
+### code chunk number 37: computation
 ###################################################
 kleinModel <- RENORM(kleinModel
                    ,INSTRUMENT = c('w2','g')
@@ -520,7 +509,7 @@ kleinModel <- RENORM(kleinModel
 
 
 ###################################################
-### code chunk number 40: bimets.Rnw:1014-1021
+### code chunk number 38: bimets.Rnw:1012-1019
 ###################################################
 with(kleinModel,TABIT(modelData$w2,
                       renorm$INSTRUMENT$w2,
@@ -532,21 +521,21 @@ with(kleinModel,TABIT(modelData$w2,
 
 
 ###################################################
-### code chunk number 41: bimets.Rnw:1028-1030
+### code chunk number 39: bimets.Rnw:1026-1028
 ###################################################
 #create a new model
 kleinRenorm <- kleinModel
 
 
 ###################################################
-### code chunk number 42: bimets.Rnw:1032-1034
+### code chunk number 40: bimets.Rnw:1030-1032
 ###################################################
 #get instruments to be used
 newInstruments <- kleinModel$renorm$INSTRUMENT
 
 
 ###################################################
-### code chunk number 43: bimets.Rnw:1036-1047
+### code chunk number 41: bimets.Rnw:1034-1045
 ###################################################
 #change exogenous by using new instruments data
 kleinRenorm$modelData <- within(kleinRenorm$modelData,
@@ -562,7 +551,7 @@ kleinRenorm$modelData <- within(kleinRenorm$modelData,
 
 
 ###################################################
-### code chunk number 44: bimets.Rnw:1049-1055
+### code chunk number 42: bimets.Rnw:1047-1053
 ###################################################
 #simulate the new model
 kleinRenorm <- SIMULATE(kleinRenorm
@@ -573,7 +562,7 @@ kleinRenorm <- SIMULATE(kleinRenorm
 
 
 ###################################################
-### code chunk number 45: bimets.Rnw:1057-1061
+### code chunk number 43: bimets.Rnw:1055-1059
 ###################################################
 #verify targets are achieved
 with(kleinRenorm$simulation,
@@ -581,3 +570,15 @@ with(kleinRenorm$simulation,
      )
 
 
+###################################################
+### code chunk number 44: bimets.Rnw:1080-1081 (eval = FALSE)
+###################################################
+## install.packages('bimets')
+
+
+###################################################
+### code chunk number 45: bimets.Rnw:1083-1084
+###################################################
+library(bimets)
+
+
